<?php die(); /* Do not remove this line */ ?>

# ===============================
# TREMENDUM TRANSCODER - PROFILES
# ===============================
#
#

# ABOUT THIS FILE:
# ================
#
# The format for this file is very simple. A line starting with a "#" character
# is considered a comment and is ignored.
#
# This configuration file contains the declarations of profiles. These profiles
# consist of a series of settings that determine the output media format and
# parameters.
#
# Profile declarations have the following format:
#   profile.key.section = value
#
#   profile: All profile declarations start with the word "profile".
#       key: Identifies the profile settings from different profiles. The
#            value for "key" must be unique to each profile settings block and
#            can contain the following characters: "-", "_", a-z, A-Z, 0-9
#   section: A predefined section name.
#     value: A value to assign to the given profile's section.
#
# A minimum profile declaration requires the following 3 sections:
#   profile.key.video_pass1
#   profile.key.audio_pass1
#   profile.key.ext
#
# All the other sections are optional, and provide extra features and control
# over the transcoding process.


# VARIABLES
# =========
#
# In order to make profile editing easier and shorter, custom variables can be
# assigned and used inside the profile values. You may want to check the
# variables section to adjust them according to your FFmpeg version.
#
# Variable declarations have the following format:
#  {$var.identifier} = value
# 
#        $var: All variable declarations include this keyword.
#  identifier: Name that identifies the variable value. The value for
#              "identifier" must be unique and can contain the following
#              characters: "-", "_", a-z, A-Z, 0-9
#       value: The value to assign to the variable. Values cannot contain
#              other variables and are limited to a single line.
#
#  Check the default profiles for examples of their usage.
#


# SECURITY NOTE
# =============
#
# Make sure that this configuration file is not writable by the web server user.


# =============================================================================
# PROFILE SECTIONS SUMMARY
# =============================================================================
#
# Below is a list of all the available profile sections for quick reference.
# Following the list there is a detailed explanation of each of these sections.
#
# profile.key.group
# profile.key.desc
# profile.key.video_pass1
# profile.key.video_pass2
# profile.key.audio_pass1
# profile.key.audio_pass2
# profile.key.ext
# profile.key.width
# profile.key.height
# profile.key.resize
# profile.key.force_divisible
# profile.key.faststart
# profile.key.deinterlace_video
# profile.key.deinterlace_mode
# profile.key.deinterlace_parity
# profile.key.deinterlace_auto
# profile.key.filename_template
# profile.key.filename_regex
# profile.key.skip_rule
# profile.key.skip_rule_invert
# profile.key.logo
# profile.key.logo_opacity
# profile.key.logo_gravity
# profile.key.logo_margin_x
# profile.key.logo_margin_y
# profile.key.text
# profile.key.text_font
# profile.key.text_size
# profile.key.text_color
# profile.key.text_opacity
# profile.key.text_gravity
# profile.key.text_margin_x
# profile.key.text_margin_y


# =============================================================================
# PROFILE SECTIONS EXPLAINED
# =============================================================================

# profile.key.group
#  Optional.
#  Default: General
#  Accepts: Text of max 256 chars. "-", "_", " ", ".", a-z, A-Z, 0-9.
#
#  Defines the name of the group to which this profile belongs.
#  Profiles with the same group are displayed under the same block
#  in the web interface.

# profile.key.desc
#  Optional.
#  Default: (key)
#  Accepts: Text.
#
#  Defines the profile description that appears in the web interface. If no
#  description is provided the profile key name is used instead.

# profile.key.video_pass1
#  Required.
#  Accepts: FFmpeg parameters (see notes)
#
#  List of parameters to pass to FFmpeg for the video encoding part.
#  Include only the parameters related to video encoding.
#
#  Use "-vn" without quotes to disable video encoding, for example to process
#  audio only.
#
#  IMPORTANT!
#    * Do not add any "-pass 1" or "-pass 2" parameters.
#    * Do not add any input / output file parameters.
#    * Do not add any video filters if you are using text or video overlays.
#    * Do not add any resize strings or filters if you have defined an output
#      width or height section.
#
#  Review the default profiles supplied with Tremendum Transcoder to understand
#  how they work.

# profile.key.video_pass2
#  Optional.
#  Default: (empty)
#  Accepts: FFmpeg parameters for 2nd pass.
#
#  If parameters are provided, they will be used for the second pass of
#  a multipass encoding. The same rules and restrictions as for "video_pass1"
#  apply here.
#
#  Notice that video_pass2 and audio_pass2 must both be empty or contain
#  parameters. When they are empty, TT will perform a single pass encoding,
#  and when they are set, TT will perform a multipass encoding.

# profile.key.audio_pass1
#  Required.
#  Accepts: FFmpeg parameters.
#
#  List of parameters to pass to FFmpeg for the audio encoding part.
#  Include only the parameters related to audio encoding.
#
#  Use "-an" without quotes to disable audio encoding, for example to process
#  video only, or for the first pass of a multipass encoding.

# profile.key.audio_pass2
#  Optional.
#  Default: (empty)
#  Accepts: FFmpeg parameters
#
#  List of parameters for the second pass audio encoding.
#
#  Notice that video_pass2 and audio_pass2 must both be empty or contain
#  parameters. When they are empty, TT will perform a single pass encoding,
#  and when they are set, TT will perform a multipass encoding.

# profile.key.ext
#  Required.
#  Accepts: Filename extension. Max 30 chars. Valid: a-z, A-Z, 0-9
#
#  Filename extension to use for the output file. For example: mp4

# profile.key.width
#  Optional
#  Default: (empty)
#  Accepts: number
#
#  Desired output width in pixels. Note that the final size may be different
#  from our desired width depending on the resize method chosen.
#  A value of 0 or empty does not resize input video.

# profile.key.height
#  Optional.
#  Default: (empty)
#  Accepts: number
#
#  Desired output height in pixels. As with the width, the final height may be
#  different depending on the resize method chosen.

# profile.key.resize
#  Optional.
#  Default: (default_resize_mode)
#  Accepts: squeeze, crop, proportional or maxside.
#
#  Specifies the desired method for resizing the input video using the values
#  supplied in the width and height section.
#
#      squeeze: Set the output dimensions to be exactly the desired width and
#               height, stretching the image to fit the dimensions.
#
#         crop: The image has the desired width and height preserving the aspect
#               ratio and discarding pixels as needed.
#
# proportional: Sets the output size proportional to the given width or height.
#               If both values are given, only width is considered.
#
#      maxside: Sets the output size so that no size is larger than the
#               specified maxside. The maxside value is taken from the width
#               setting.

# profile.key.force_divisible
#  Optional.
#  Default: (default_force_divisible)
#  Accepts: true or false.
#
#  When set, resize operations make sure that the target pixel dimensions are
#  even (divisible by 2).
#
#  This is useful when dealing with profiles that use codecs that do not support
#  odd image dimensions.

# profile.key.faststart
#  Optional
#  Default: false
#  Accepts: true or false.
#
#  When set to true, performs a fast start optimization on the resulting
#  video files. This is good for progressive download and pseudo-streaming, so
#  the video can start playing as it is being downloaded, without the need to
#  wait to buffer the full video.
#
#  This optimization if performed to FLV files using the program setup for
#  "flvtool2_cmd", and to MP4 and MOV files using the program setup for
#  "faststart_cmd" in the config file.

# profile.key.deinterlace_video
#  Optional
#  Default: false
#  Accepts: true or false.
#
#  When set to true, the source video gets deinterlaced.
#  For more information about video interlacing you can check:
#  http://en.wikipedia.org/wiki/Interlaced_video
#
#  This option utilizes yadif filter when possible.

# profile.key.deinterlace_mode
#  Optional
#  Default: 0
#  Accepts: 0, 1, 2, 3
#
#  Specifies the interlacing mode to utilize.
#    0: output 1 frame for each frame
#    1: output 1 frame for each field 
#    2: output 1 frame for each frame, but skip spatial interlacing check
#    3: output 1 frame for each field, but skip spatial interlacing check 

# profile.key.deinterlace_parity
#  Optional
#  Default: -1
#  Accepts: -1, 0, 1
#
#  Specifies the picture field parity to assume for the interlaced video source.
#   -1: automatic detection
#    0: top field first
#    1: bottom field first

# profile.key.deinterlace_auto
#  Optional
#  Default: 0
#  Accepts: 0, 1
#
#  This option specifies if the deinterlacer should trust the interlaced flag
#  and only deinterlace frames marked as interlaced, or deinterlace all frames.
#    0: deinterlace all frames
#    1: only deinterlace frames marked as interlaced

# profile.key.filename_template
#  Optional.
#  Default: (default_filename_template)
#  Accepts: text and filename template variables.
#
#  Allows to define specific file naming for the current profile.
#
#  If not defined, the default_filename_template value from the config is used.
#  For a quick list of available variables, check this document.
#  For a detailed explanation of filename templates, check the section for
#  "DEFAULT FILENAME TEMPLATES" in config.inc.php.

# profile.key.filename_regex
#  Optional.
#  Default: (default_filename_regex)
#  Accepts: Perl Compatible Regular Expression without delimiters or modifiers.
#
#  Allows to define specific Perl Compatible Regular Expression to capture
#  groups of text to use in filename templates.
#  If not defined, the default_filename_regex value from the config is used.

# profile.key.skip_rule
#  Optional
#  Default: (empty)
#  Accepts: Defined set of comparison operators condition (see below)
#
#  This section allows us to define a certain rule to check against the source
#  video dimensions. If the rule matches the defined conditions, the processing
#  of the input file is skipped and a message is shown in the log.
#
#  This is particularly useful to limit certain profiles to certain source
#  video dimensions.
#
#  For example assume we have a profile to convert the source videos to
#  1920x1080 full HD MP4 video file at 8 mbps and the source folder contains
#  some videos which are 320x240 pixels. We could set "skip_rule = width < 640"
#  and this would effectively ignore any source video smaller than 640 pixels
#  in width.
#
#  The format for the condition is:
#    DIMENSION COMPARISON number
#    DIMENSION COMPARISON number OPERATOR DIMENSION COMPARISON number
#
#  Where DIMENSION is: width or height. (w or h can be used for shortness)
#  Where COMPARISON is one of the following:
#    < , lt        (less than)
#    <=, le        (less or equal to)
#    > , gt        (greater than)
#    >=, ge        (greater or equal to)
#    ==, =, eq     (equal to)
#    !=, <>, ne    (not equal to)
#
#  Where number is: A regular number. i.e. 320.
#  Where OPERATOR is: AND or OR.
#
#  Example values:
#
#  Skip odd sized source videos.
#  width = 640 AND height > 500.
#
#  Skip videos smaller than 640 pixels in width, or exact dimension of 720x480.
#  width < 640 OR width = 720 AND height = 480

# profile.key.skip_rule_invert
#  Optional.
#  Default: false.
#  Accepts: true or false.
#
#  When set to true, the logic of the action is inverted.
#
#  This is useful to skip all the videos except the ones matched by the
#  skip_rule, effectively inverting the logic.
#
#  For example:
#    "skip_rule = width = 640 AND height = 480"
#    "skip_rule_invert = true"
#
#  This would effectively process only source videos that are 640x480, ignoring
#  any other videos.

# profile.key.logo
#  Optional.
#  Default: (empty)
#  Accepts: Full path to image or video file.
#
#  Specify the full path to an image or video file to put on top of the source
#  video. This is useful when creating watermarks or adding a company logo.
#
#  Note that the logo dimensions must be smaller than the source video.
#  For better results, use 24 bit PNG images with transparency.

# profile.key.logo_opacity
#  Optional.
#  Default: 255
#  Accepts: Number between 0 and 255.
#
#  Defines the opacity of the logo image in relation to the source video.
#  A value of 0 is total transparency, and 255 is normal. Numbers in between
#  set the amount of transparency.

# profile.key.logo_gravity
#  Optional.
#  Default: 1
#  Accepts: Number between 1 and 9
#
#  Defines the position of the logo in relation to the source video as
#  coordinates from a keypad.
#
#  Possible values are:
#    1 (top left)        2 (top center)      3 (top right)
#    4 (middle left)     5 (middle center)   6 (middle right)
#    7 (bottom left)     8 (bottom center)   9 (bottom right)
#

# profile.key.logo_margin_x
#  Optional.
#  Default: 0
#  Accepts: number
#
#  Sets the horizontal margin size in pixels.

# profile.key.logo_margin_y
#  Optional.
#  Default: 0
#  Accepts: number
#
#  Sets the vertical margin size in pixels.

# profile.key.text
#  Optional.
#  Default: (empty)
#  Accepts: Text
#
#  Allows to overlay a defined text on top of the source video.

# profile.key.text_font
#  Optional.
#  Default: (default_text_font)
#  Accepts: Full path to true type font file.
#
#  Specify the location of the font file to be used to generate the text overlay.

# profile.key.text_size
#  Optional.
#  Default: 18
#  Accepts: Number
#
#  Defines the text size in pixels.

# profile.key.text_color
#  Optional.
#  Default: ffffff (white)
#  Accepts: Six digit hexadecimal value
#
#  Defines the color of the text overlay. For a quick color reference check:
#  https://en.wikipedia.org/wiki/Web_colors

# profile.key.text_opacity
#  Optional.
#  Default: 255
#  Accepts: Number between 0 and 255.
#
#  Defines the opacity of the text in relation to the source video.
#  A value of 0 is total transparency, and 255 is normal. Numbers in between
#  set the amount of transparency.

# profile.key.text_gravity
#  Optional.
#  Default: 1
#  Accepts: Number between 1 and 9
#
#  Defines the position of the text in relation to the source video as
#  coordinates from a keypad. (see logo_gravity for details)

# profile.key.text_margin_x
#  Optional.
#  Default: 0
#  Accepts: number
#
#  Sets the horizontal margin size in pixels.

# profile.key.text_margin_y
#  Optional.
#  Default: 0
#  Accepts: number
#
#  Sets the horizontal margin size in pixels.


# =============================================================================
# VARIABLES FOR USE IN FILENAME TEMPLATES
# =============================================================================
#
# Below is a list of the available variables to use in filename templates.
# For more information about their values and usage, please check the
# documentation under "DEFAULT FILENAME TEMPLATES" in config.inc.php file.
#
# STANDARD VARIABLES:
#
# %sourcename%
# %sourceext%
# %format%
# %ext%
# %width%
# %height%
# %outputwidth%
# %outputheight%
# %sourcewidth%
# %sourceheight%
#
# REGULAR EXPRESSION BASED VARIABLES:
#
# %rx1%, %rx2%, %rxN%
# %rx1#sourcename%, %rxN#VARIABLE%
# %rx1=LiteralContent%, %rxN=LiteralContent%




###############################################################################
##                                                                           ##
## VARIABLES AND PROFILES CONFIGURATION STARTS HERE.                         ##
##                                                                           ##
###############################################################################



# =============================================================================
# COMPATIBILITY VARIABLES
# =============================================================================
# 
# Because different versions of FFmpeg accept different parameters syntax, we
# make use of variables to quickly change those parameters. This makes it easier
# to upgrade FFmpeg versions and adapt your profiles accordingly.

# Video bitrate parameter.
# Since 0.9 the preferred syntax is "b:v", previous versions use "b" or "vb".
# Comment or uncomment according to your version.
#
#{$var.vb} = b
{$var.vb} = b:v

# Audio bitrate parameter.
# Since 0.9 the preferred syntax is "b:a", previous versions use "ab".
# Comment or uncomment according to your version.
#
#{$var.ab} = ab
{$var.ab} = b:a

# Video profile paramenter.
# Since 0.11 the preferred syntax is "profile:v", previous versions use "profile".
# Comment or uncomment according to your version.
#{$var.profile} = profile
{$var.profile} = profile:v

# =============================================================================
# COMPRESSION PRESET VARIABLES
# =============================================================================
#
# Adjust the following varables according to your version of FFmpeg.
#

# h.264 Preset variables for FFmpeg version <= 0.9
# Comment or uncomment according to your version.
#
#{$var.h264_fast_firstpass}   = -coder 1 -flags +loop -cmp +chroma -partitions -parti8x8-parti4x4-partp8x8-partb8x8 -me_method dia -subq 2 -me_range 16 -g 250 -keyint_min 25 -sc_threshold 40 -i_qfactor 0.71 -b_strategy 1 -qcomp 0.6 -qmin 10 -qmax 51 -qdiff 4 -bf 3 -refs 1 -directpred 1 -trellis 0 -flags2 +bpyramid-mixed_refs+wpred-dct8x8+fastpskip -wpredp 2 -rc_lookahead 30
#{$var.h264_fast}             = -coder 1 -flags +loop -cmp +chroma -partitions +parti8x8+parti4x4+partp8x8+partb8x8 -me_method hex -subq 6 -me_range 16 -g 250 -keyint_min 25 -sc_threshold 40 -i_qfactor 0.71 -b_strategy 1 -qcomp 0.6 -qmin 10 -qmax 51 -qdiff 4 -bf 3 -refs 2 -directpred 1 -trellis 1 -flags2 +bpyramid+mixed_refs+wpred+dct8x8+fastpskip -wpredp 2 -rc_lookahead 30
#{$var.h264_medium_firstpass} = -coder 1 -flags +loop -cmp +chroma -partitions -parti8x8-parti4x4-partp8x8-partb8x8 -me_method dia -subq 2 -me_range 16 -g 250 -keyint_min 25 -sc_threshold 40 -i_qfactor 0.71 -b_strategy 1 -qcomp 0.6 -qmin 10 -qmax 51 -qdiff 4 -bf 3 -refs 1 -directpred 1 -trellis 0 -flags2 +bpyramid-mixed_refs+wpred-dct8x8+fastpskip -wpredp 2
#{$var.h264_medium}           = -coder 1 -flags +loop -cmp +chroma -partitions +parti8x8+parti4x4+partp8x8+partb8x8 -me_method hex -subq 7 -me_range 16 -g 250 -keyint_min 25 -sc_threshold 40 -i_qfactor 0.71 -b_strategy 1 -qcomp 0.6 -qmin 10 -qmax 51 -qdiff 4 -bf 3 -refs 3 -directpred 1 -trellis 1 -flags2 +bpyramid+mixed_refs+wpred+dct8x8+fastpskip -wpredp 2
#{$var.h264_ipod320}          = -coder 0 -bf 0 -flags2 -wpred-dct8x8 -level 13 -maxrate 768000 -bufsize 3000000
#{$var.h264_ipod640}          = -coder 0 -bf 0 -refs 1 -flags2 -wpred-dct8x8 -level 30 -maxrate 10000000 -bufsize 10000000
#{$var.h264_main}             = -flags2 -dct8x8
#{$var.h264_baseline}         = -coder 0 -bf 0 -flags2 -wpred-dct8x8 -wpredp 0

# h.264 preset variables for FFmpeg version >= 0.10
# Comment or uncomment according to your version.
#
{$var.h264_fast_firstpass}   = -preset fast
{$var.h264_fast}             = -preset fast
{$var.h264_medium_firstpass} = -preset medium
{$var.h264_medium}           = -preset medium
{$var.h264_main}             = -vprofile main
{$var.h264_baseline}         = -vprofile baseline

# VPX base preset variables, without: vb, maxrate, minrate, qmax, qmin, slices, profile
{$var.vpx_base} = -g 120 -rc_lookahead 16 -quality good -speed 0 -arnr_max_frames 7 -arnr_strength 5 -arnr_type 3

# AAC audio encoding library.
# Select the library according to the one available in your FFmpeg install.
# You can use tt-diag.php to determine which one is available.
# Comment or uncomment according to your version.
#
#{$var.AAC_LIB} = libfaac
#{$var.AAC_LIB} = libfdk_aac
{$var.AAC_LIB} = libvo_aacenc



# =============================================================================
# PROFILE DEFINITIONS
# =============================================================================
#
# Below starts the list of default profiles. Observe them and customize them
# as required.
#
# Also remember that we offer a profile customization service, so we can
# tailor the profiles to your needs and you don't need to worry about the
# technical details.
#
# Check our website for more information.
# http://1stdev.com



# =============================================================================
# FEATURES DEMONSTRATION PROFILES
# =============================================================================
#
# The following profiles demostrate the use of text and image overlays.
# Adjust logo and text_font values to the location in your server.
#

# Demo featuring proportional resize, logo and text overlays.
profile.demo1.group             = Demo
profile.demo1.desc              = 640x360 Proportional resize + Logo + Text overlay
profile.demo1.video_pass1       = -vcodec libx264 -threads 0 -g 30 -{$var.vb} 1300k -bt 1300k {$var.h264_fast} {$var.h264_baseline}
profile.demo1.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.demo1.ext               = mp4
profile.demo1.width             = 640
profile.demo1.height            = 360
profile.demo1.resize            = proportional
profile.demo1.force_divisible   = true
profile.demo1.logo              = /path/to/tt-private/media/logos/tt_logo_small.png
profile.demo1.logo_margin_x     = 10
profile.demo1.logo_margin_y     = 20
profile.demo1.logo_gravity      = 9
profile.demo1.logo_opacity      = 255
profile.demo1.text              = TremendumTranscoder.com
profile.demo1.text_color        = ffffff
profile.demo1.text_size         = 20
profile.demo1.text_font         = /path/to/tt-private/media/fonts/Droid-Serif/DroidSerif-Regular.ttf
profile.demo1.text_gravity      = 3
profile.demo1.text_margin_x     = 10
profile.demo1.text_margin_y     = 10
profile.demo1.text_opacity      = 230
profile.demo1.deinterlace_video = true
profile.demo1.deinterlace_auto  = 1

# Crop demo: Horizontal banner + Text overlay
profile.demo2.group             = Demo
profile.demo2.desc              = 728x90 Banner style crop + Text overlay demo
profile.demo2.video_pass1       = -vcodec libx264 -threads 0 -g 30 -{$var.vb} 384k -bt 384k {$var.h264_fast} {$var.h264_baseline}
profile.demo2.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 64k
profile.demo2.ext               = mp4
profile.demo2.width             = 728
profile.demo2.height            = 90
profile.demo2.resize            = crop
profile.demo2.faststart         = false
profile.demo2.text              = TremendumTranscoder.com
profile.demo2.text_color        = ffffff
profile.demo2.text_size         = 20
profile.demo2.text_font         = /path/to/tt-private/media/fonts/Droid-Serif/DroidSerif-Regular.ttf
profile.demo2.text_gravity      = 3
profile.demo2.text_margin_x     = 10
profile.demo2.text_margin_y     = 10
profile.demo2.text_opacity      = 230
profile.demo2.deinterlace_video = true
profile.demo2.deinterlace_auto  = 1

# Crop demo: Vertical skyscraper banner + Logo overlay
profile.demo3.group             = Demo
profile.demo3.desc              = 120x600 Skyscraper style crop + Logo overlay demo
profile.demo3.video_pass1       = -vcodec libx264 -threads 0 -g 30 -{$var.vb} 384k -bt 384k {$var.h264_fast} {$var.h264_baseline}
profile.demo3.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 64k
profile.demo3.ext               = mp4
profile.demo3.width             = 120
profile.demo3.height            = 600
profile.demo3.resize            = crop
profile.demo3.faststart         = false
profile.demo3.logo              = /path/to/tt-private/media/logos/tt_logo_small.png
profile.demo3.logo_margin_x     = 0
profile.demo3.logo_margin_y     = 10
profile.demo3.logo_gravity      = 8
profile.demo3.logo_opacity      = 255
profile.demo3.deinterlace_video = true
profile.demo3.deinterlace_auto  = 1


# =============================================================================
# DEFAULT VIDEO ENCODING PROFILES
# =============================================================================
#

# WEBM PROFILES
# =============
#
# WebM is an open, royalty-free media file format designed for the web.
# FFmpeg conversion params
#    http://ffmpeg.org/ffmpeg.html#libvpx
#
# WebM encoding paramenters guide
#    http://www.webmproject.org/tools/encoder-parameters/
#

# WebM 360p, 2pass
profile.webm_360_2p.group             = WebM
profile.webm_360_2p.desc              = WebM 360p, 768k (multipass)
profile.webm_360_2p.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 768k -maxrate 1.5M -minrate 40k -qmax 63 -qmin 0 -{$var.profile} 0 {$var.vpx_base}
profile.webm_360_2p.video_pass2       = -f webm -vcodec libvpx -{$var.vb} 768k -maxrate 1.5M -minrate 40k -qmax 63 -qmin 0 -{$var.profile} 0 {$var.vpx_base}
profile.webm_360_2p.audio_pass1       = -an
profile.webm_360_2p.audio_pass2       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.webm_360_2p.ext               = webm
profile.webm_360_2p.width             = 640
profile.webm_360_2p.height            = 360
profile.webm_360_2p.resize            = proportional
profile.webm_360_2p.force_divisible   = true
profile.webm_360_2p.skip_rule         = width < 640
profile.webm_360_2p.deinterlace_video = true
profile.webm_360_2p.deinterlace_auto  = 1
#profile.webm_360_2p.filename_template = %sourcename%-%format%.%ext%

# WebM 480p, 2pass
profile.webm_480_2p.group             = WebM
profile.webm_480_2p.desc              = WebM 480p, 1000k (multipass)
profile.webm_480_2p.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 1M -maxrate 2.5M -minrate 75k -qmax 60 -qmin 3 -{$var.profile} 0 {$var.vpx_base}
profile.webm_480_2p.video_pass2       = -f webm -vcodec libvpx -{$var.vb} 1M -maxrate 2.5M -minrate 75k -qmax 60 -qmin 3 -{$var.profile} 0 {$var.vpx_base}
profile.webm_480_2p.audio_pass1       = -an
profile.webm_480_2p.audio_pass2       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.webm_480_2p.ext               = webm
profile.webm_480_2p.width             = 854
profile.webm_480_2p.height            = 480
profile.webm_480_2p.resize            = proportional
profile.webm_480_2p.force_divisible   = true
profile.webm_480_2p.skip_rule         = width < 854
profile.webm_480_2p.deinterlace_video = true
profile.webm_480_2p.deinterlace_auto  = 1
#profile.webm_480_2p.filename_template = %sourcename%-%format%.%ext%

# WebM 720p, 2pass
profile.webm_720_2p.group             = WebM
profile.webm_720_2p.desc              = WebM 720p, 2000k (multipass)
profile.webm_720_2p.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 2M -maxrate 24M -minrate 100k -qmax 51 -qmin 11 -{$var.profile} 0 -slices 2 {$var.vpx_base}
profile.webm_720_2p.video_pass2       = -f webm -vcodec libvpx -{$var.vb} 2M -maxrate 24M -minrate 100k -qmax 51 -qmin 11 -{$var.profile} 0 -slices 2 {$var.vpx_base}
profile.webm_720_2p.audio_pass1       = -an
profile.webm_720_2p.audio_pass2       = -acodec libvorbis -ar 48000 -ac 2 -{$var.ab} 192k
profile.webm_720_2p.ext               = webm
profile.webm_720_2p.width             = 1280
profile.webm_720_2p.height            = 720
profile.webm_720_2p.resize            = proportional
profile.webm_720_2p.force_divisible   = true
profile.webm_720_2p.skip_rule         = width < 1280
profile.webm_720_2p.deinterlace_video = true
profile.webm_720_2p.deinterlace_auto  = 1
#profile.webm_720_2p.filename_template = %sourcename%-%format%.%ext%

# WebM 1080p, 2pass
profile.webm_1080_2p.group             = WebM
profile.webm_1080_2p.desc              = WebM 1080p, 4000k (multipass)
profile.webm_1080_2p.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 4M -maxrate 24M -minrate 100k -qmax 51 -qmin 11 -{$var.profile} 1 -slices 2 {$var.vpx_base}
profile.webm_1080_2p.video_pass2       = -f webm -vcodec libvpx -{$var.vb} 4M -maxrate 24M -minrate 100k -qmax 51 -qmin 11 -{$var.profile} 1 -slices 2 {$var.vpx_base}
profile.webm_1080_2p.audio_pass1       = -an
profile.webm_1080_2p.audio_pass2       = -acodec libvorbis -ar 48000 -ac 2 -{$var.ab} 192k
profile.webm_1080_2p.ext               = webm
profile.webm_1080_2p.width             = 1920
profile.webm_1080_2p.height            = 1080
profile.webm_1080_2p.resize            = proportional
profile.webm_1080_2p.force_divisible   = true
profile.webm_1080_2p.skip_rule         = width < 1920
profile.webm_1080_2p.deinterlace_video = true
profile.webm_1080_2p.deinterlace_auto  = 1
#profile.webm_1080_2p.filename_template = %sourcename%-%format%.%ext%

# WebM 360p, 1 pass
profile.webm_360.group             = WebM
profile.webm_360.desc              = WebM 360p, 768k 
profile.webm_360.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 768k -maxrate 1.5M -minrate 40k -qmax 63 -qmin 0 -{$var.profile} 0 {$var.vpx_base}
profile.webm_360.audio_pass1       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.webm_360.ext               = webm
profile.webm_360.width             = 640
profile.webm_360.height            = 360
profile.webm_360.resize            = proportional
profile.webm_360.force_divisible   = true
profile.webm_360.skip_rule         = width < 640
profile.webm_360.deinterlace_video = true
profile.webm_360.deinterlace_auto  = 1
#profile.webm_360.filename_template = %sourcename%-%format%.%ext%

# WebM 480p, 1pass
profile.webm_480.group             = WebM
profile.webm_480.desc              = WebM 480p, 1000k 
profile.webm_480.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 1M -maxrate 2.5M -minrate 75k -qmax 60 -qmin 3 -{$var.profile} 0 {$var.vpx_base}
profile.webm_480.audio_pass1       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.webm_480.ext               = webm
profile.webm_480.width             = 854
profile.webm_480.height            = 480
profile.webm_480.resize            = proportional
profile.webm_480.force_divisible   = true
profile.webm_480.skip_rule         = width < 854
profile.webm_480.deinterlace_video = true
profile.webm_480.deinterlace_auto  = 1
#profile.webm_480.filename_template = %sourcename%-%format%.%ext%

# WebM 720p, 1pass
profile.webm_720.group             = WebM
profile.webm_720.desc              = WebM 720p, 2000k 
profile.webm_720.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 2M -maxrate 24M -minrate 100k -qmax 51 -qmin 11 -{$var.profile} 0 -slices 2 {$var.vpx_base}
profile.webm_720.audio_pass1       = -acodec libvorbis -ar 48000 -ac 2 -{$var.ab} 192k
profile.webm_720.ext               = webm
profile.webm_720.width             = 1280
profile.webm_720.height            = 720
profile.webm_720.resize            = proportional
profile.webm_720.force_divisible   = true
profile.webm_720.skip_rule         = width < 1280
profile.webm_720.deinterlace_video = true
profile.webm_720.deinterlace_auto  = 1
#profile.webm_720.filename_template = %sourcename%-%format%.%ext%

# WebM 1080p
profile.webm_1080.group             = WebM
profile.webm_1080.desc              = WebM 1080p, 4000k 
profile.webm_1080.video_pass1       = -f webm -vcodec libvpx -{$var.vb} 4M -maxrate 24M -minrate 100k -qmax 51 -qmin 11 -{$var.profile} 1 -slices 2 {$var.vpx_base}
profile.webm_1080.audio_pass1       = -acodec libvorbis -ar 48000 -ac 2 -{$var.ab} 192k
profile.webm_1080.ext               = webm
profile.webm_1080.width             = 1920
profile.webm_1080.height            = 1080
profile.webm_1080.resize            = proportional
profile.webm_1080.force_divisible   = true
profile.webm_1080.skip_rule         = width < 1920
profile.webm_1080.deinterlace_video = true
profile.webm_1080.deinterlace_auto  = 1
#profile.webm_1080.filename_template = %sourcename%-%format%.%ext%



# Theora + Vorbis in Ogg container
# ================================
#
# Theora video
# http://theora.org/
#
# Vorbis audio (8kHz-48.0kHz, 6 to 128 kbps/channel)
# http://xiph.org/vorbis/
#

# Theora 360p, 2 pass
profile.theora_360p_2p.group             = Ogg Theora
profile.theora_360p_2p.desc              = Ogg Theora + Vorbis 360p, 1300k (multipass)
profile.theora_360p_2p.video_pass1       = -vcodec libtheora -g 120 -{$var.vb} 1300k
profile.theora_360p_2p.video_pass2       = -vcodec libtheora -g 120 -{$var.vb} 1300k
profile.theora_360p_2p.audio_pass1       = -an
profile.theora_360p_2p.audio_pass2       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.theora_360p_2p.ext               = ogg
profile.theora_360p_2p.width             = 640
profile.theora_360p_2p.height            = 360
profile.theora_360p_2p.resize            = proportional
profile.theora_360p_2p.force_divisible   = true
profile.theora_360p_2p.deinterlace_video = true
profile.theora_360p_2p.deinterlace_auto  = 1

# Theora 480p, 2 pass
profile.theora_480p_2p.group             = Ogg Theora
profile.theora_480p_2p.desc              = Ogg Theora + Vorbis 480p, 2100k (multipass)
profile.theora_480p_2p.video_pass1       = -vcodec libtheora -g 120 -{$var.vb} 2100k
profile.theora_480p_2p.video_pass2       = -vcodec libtheora -g 120 -{$var.vb} 2100k
profile.theora_480p_2p.audio_pass1       = -an
profile.theora_480p_2p.audio_pass2       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.theora_480p_2p.ext               = ogg
profile.theora_480p_2p.width             = 854
profile.theora_480p_2p.height            = 480
profile.theora_480p_2p.resize            = proportional
profile.theora_480p_2p.force_divisible   = true
profile.theora_480p_2p.deinterlace_video = true
profile.theora_480p_2p.deinterlace_auto  = 1

# Theora 720p, 2 pass
profile.theora_720p_2p.group             = Ogg Theora
profile.theora_720p_2p.desc              = Ogg Theora + Vorbis 720p, 2500k (multipass)
profile.theora_720p_2p.video_pass1       = -vcodec libtheora -g 120 -{$var.vb} 2500k
profile.theora_720p_2p.video_pass2       = -vcodec libtheora -g 120 -{$var.vb} 2500k
profile.theora_720p_2p.audio_pass1       = -an
profile.theora_720p_2p.audio_pass2       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.theora_720p_2p.ext               = ogg
profile.theora_720p_2p.width             = 1280
profile.theora_720p_2p.height            = 720
profile.theora_720p_2p.resize            = proportional
profile.theora_720p_2p.force_divisible   = true
profile.theora_720p_2p.deinterlace_video = true
profile.theora_720p_2p.deinterlace_auto  = 1

# Theora 1080p, 2 pass
profile.theora_1080p_2p.group             = Ogg Theora
profile.theora_1080p_2p.desc              = Ogg Theora + Vorbis 1080p, 4000k (multipass)
profile.theora_1080p_2p.video_pass1       = -vcodec libtheora -g 120 -{$var.vb} 4000k
profile.theora_1080p_2p.video_pass2       = -vcodec libtheora -g 120 -{$var.vb} 4000k
profile.theora_1080p_2p.audio_pass1       = -an
profile.theora_1080p_2p.audio_pass2       = -acodec libvorbis -ar 48000 -ac 2 -{$var.ab} 192k
profile.theora_1080p_2p.ext               = ogg
profile.theora_1080p_2p.width             = 1920
profile.theora_1080p_2p.height            = 1080
profile.theora_1080p_2p.resize            = proportional
profile.theora_1080p_2p.force_divisible   = true
profile.theora_1080p_2p.deinterlace_video = true
profile.theora_1080p_2p.deinterlace_auto  = 1

# Theora 360p, 1 pass
profile.theora_360p.group             = Ogg Theora
profile.theora_360p.desc              = Ogg Theora + Vorbis 360p, 1300k 
profile.theora_360p.video_pass1       = -vcodec libtheora -g 60 -{$var.vb} 1300k
profile.theora_360p.audio_pass1       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.theora_360p.ext               = ogg
profile.theora_360p.width             = 640
profile.theora_360p.height            = 360
profile.theora_360p.resize            = proportional
profile.theora_360p.force_divisible   = true
profile.theora_360p.deinterlace_video = true
profile.theora_360p.deinterlace_auto  = 1

# Theora 480p, 1 pass
profile.theora_480p.group             = Ogg Theora
profile.theora_480p.desc              = Ogg Theora + Vorbis 480p, 2100k 
profile.theora_480p.video_pass1       = -vcodec libtheora -g 60 -{$var.vb} 2100k
profile.theora_480p.audio_pass1       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.theora_480p.ext               = ogg
profile.theora_480p.width             = 854
profile.theora_480p.height            = 480
profile.theora_480p.resize            = proportional
profile.theora_480p.force_divisible   = true
profile.theora_480p.deinterlace_video = true
profile.theora_480p.deinterlace_auto  = 1

# Theora 720p, 1 pass
profile.theora_720p.group             = Ogg Theora
profile.theora_720p.desc              = Ogg Theora + Vorbis 720p, 2500k 
profile.theora_720p.video_pass1       = -vcodec libtheora -g 60 -{$var.vb} 2500k
profile.theora_720p.audio_pass1       = -acodec libvorbis -ar 44100 -ac 2 -{$var.ab} 128k
profile.theora_720p.ext               = ogg
profile.theora_720p.width             = 1280
profile.theora_720p.height            = 720
profile.theora_720p.resize            = proportional
profile.theora_720p.force_divisible   = true
profile.theora_720p.deinterlace_video = true
profile.theora_720p.deinterlace_auto  = 1

# Theora 1080p, 1 pass
profile.theora_1080p.group             = Ogg Theora
profile.theora_1080p.desc              = Ogg Theora + Vorbis 1080p, 4000k 
profile.theora_1080p.video_pass1       = -vcodec libtheora -g 60 -{$var.vb} 4000k
profile.theora_1080p.audio_pass1       = -acodec libvorbis -ar 48000 -ac 2 -{$var.ab} 192k
profile.theora_1080p.ext               = ogg
profile.theora_1080p.width             = 1920
profile.theora_1080p.height            = 1080
profile.theora_1080p.resize            = proportional
profile.theora_1080p.force_divisible   = true
profile.theora_1080p.deinterlace_video = true
profile.theora_1080p.deinterlace_auto  = 1


# MP4 H.264 VIDEO + AAC AUDIO PROFILES
# ====================================
#
# Mulipass profiles.

# 640x360 h264 Main profile @ level 3.0 (1300k) Compatible with iPhone 4, iPad, Desktop.
profile.mp4_360_2p.group             = Mp4 h.264
profile.mp4_360_2p.desc              = MP4 640x360 h264 Main profile @ level 3.0, 1300k (multipass)
profile.mp4_360_2p.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 1300k -bt 1300k {$var.h264_fast_firstpass} {$var.h264_main}
profile.mp4_360_2p.video_pass2       = -vcodec libx264 -threads 0 -{$var.vb} 1300k -bt 1300k {$var.h264_fast} {$var.h264_main}
profile.mp4_360_2p.audio_pass1       = -an
profile.mp4_360_2p.audio_pass2       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_360_2p.ext               = mp4
profile.mp4_360_2p.width             = 640
profile.mp4_360_2p.height            = 360
profile.mp4_360_2p.resize            = proportional
profile.mp4_360_2p.force_divisible   = true
profile.mp4_360_2p.faststart         = true
profile.mp4_360_2p.filename_template =
profile.mp4_360_2p.deinterlace_video = true
profile.mp4_360_2p.deinterlace_auto  = 1

# 854x480 h264 Main profile @ level 3.1 (2100k) Compatible with iPhone 4, iPad, DEsktop.
# Note: 4:3 source video generates proportioanl 640x480, which fall in profile level 3.0
profile.mp4_480_2p.group             = Mp4 h.264
profile.mp4_480_2p.desc              = MP4 854x480 h264 Main profile @ level 3.1, 2100k (multipass)
profile.mp4_480_2p.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 2100k -bt 2100k {$var.h264_fast_firstpass} {$var.h264_main}
profile.mp4_480_2p.video_pass2       = -vcodec libx264 -threads 0 -{$var.vb} 2100k -bt 2100k {$var.h264_fast} {$var.h264_main}
profile.mp4_480_2p.audio_pass1       = -an
profile.mp4_480_2p.audio_pass2       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_480_2p.ext               = mp4
profile.mp4_480_2p.width             = 854
profile.mp4_480_2p.height            = 480
profile.mp4_480_2p.resize            = proportional
profile.mp4_480_2p.force_divisible   = true
profile.mp4_480_2p.faststart         = true
profile.mp4_480_2p.filename_template =
profile.mp4_480_2p.deinterlace_video = true
profile.mp4_480_2p.deinterlace_auto  = 1

# 1280x720 h264 Main profile @ level 3.1 (2500 kbps)
profile.mp4_720_2p.group             = Mp4 h.264
profile.mp4_720_2p.desc              = MP4 1280x720 h264 Main profile @ level 3.1, 2500k (multipass)
profile.mp4_720_2p.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 2500k -bt 2500k {$var.h264_fast_firstpass} {$var.h264_main}
profile.mp4_720_2p.video_pass2       = -vcodec libx264 -threads 0 -{$var.vb} 2500k -bt 2500k {$var.h264_fast} {$var.h264_main}
profile.mp4_720_2p.audio_pass1       = -an
profile.mp4_720_2p.audio_pass2       = -acodec {$var.AAC_LIB} -ar 48000 -ac 2 -{$var.ab} 192k
profile.mp4_720_2p.ext               = mp4
profile.mp4_720_2p.width             = 1280
profile.mp4_720_2p.height            = 720
profile.mp4_720_2p.resize            = proportional
profile.mp4_720_2p.force_divisible   = true
profile.mp4_720_2p.faststart         = true
profile.mp4_720_2p.filename_template =
profile.mp4_720_2p.deinterlace_video = true
profile.mp4_720_2p.deinterlace_auto  = 1

# 1920x1080 h264 High profile @ level 4.0 (8000kbps)
profile.mp4_1080_2p.group             = Mp4 h.264
profile.mp4_1080_2p.desc              = MP4 1920x1080 h264 High profile @ level 4.0, 8000k (multipass)
profile.mp4_1080_2p.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 8000k -bt 8000k {$var.h264_fast_firstpass}
profile.mp4_1080_2p.video_pass2       = -vcodec libx264 -threads 0 -{$var.vb} 8000k -bt 8000k {$var.h264_fast}
profile.mp4_1080_2p.audio_pass1       = -an
profile.mp4_1080_2p.audio_pass2       = -acodec {$var.AAC_LIB} -ar 48000 -ac 2 -{$var.ab} 192k
profile.mp4_1080_2p.ext               = mp4
profile.mp4_1080_2p.width             = 1920
profile.mp4_1080_2p.height            = 1080
profile.mp4_1080_2p.resize            = proportional
profile.mp4_1080_2p.force_divisible   = true
profile.mp4_1080_2p.faststart         = true
profile.mp4_1080_2p.filename_template =
profile.mp4_1080_2p.deinterlace_video = true
profile.mp4_1080_2p.deinterlace_auto  = 1

# Single pass profiles

# 640x360 h264 Main profile @ level 3.0 (1300k) Compatible with iPhone 4, iPad, Desktop.
profile.mp4_360.group             = Mp4 h.264
profile.mp4_360.desc              = MP4 640x360 h264 Main profile @ level 3.0, 1300k
profile.mp4_360.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 1300k -bt 1300k {$var.h264_fast} {$var.h264_main}
profile.mp4_360.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_360.ext               = mp4
profile.mp4_360.width             = 640
profile.mp4_360.height            = 360
profile.mp4_360.resize            = proportional
profile.mp4_360.force_divisible   = true
profile.mp4_360.faststart         = true
profile.mp4_360.filename_template =
profile.mp4_360.deinterlace_video = true
profile.mp4_360.deinterlace_auto  = 1

# 854x480 h264 Main profile @ level 3.1 (2100k) Compatible with iPhone 4, iPad, Desktop.
# Note: 4:3 source video generates proportioanl 640x480, which fall in profile level 3.0
profile.mp4_480.group             = Mp4 h.264
profile.mp4_480.desc              = MP4 854x480 h264 Main profile @ level 3.1, 2100k
profile.mp4_480.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 2100k -bt 2100k {$var.h264_fast} {$var.h264_main}
profile.mp4_480.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_480.ext               = mp4
profile.mp4_480.width             = 854
profile.mp4_480.height            = 480
profile.mp4_480.resize            = proportional
profile.mp4_480.force_divisible   = true
profile.mp4_480.faststart         = true
profile.mp4_480.filename_template =
profile.mp4_480.deinterlace_video = true
profile.mp4_480.deinterlace_auto  = 1

# 1280x720 h264 Main profile @ level 3.1 (2500 kbps), Compatible with iPhone 4, iPad, DEsktop.
profile.mp4_720.group             = Mp4 h.264
profile.mp4_720.desc              = MP4 1280x720 h264 Main profile @ level 3.1, 2500k
profile.mp4_720.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 2500k -bt 2500k {$var.h264_fast} {$var.h264_main}
profile.mp4_720.audio_pass1       = -acodec {$var.AAC_LIB} -ar 48000 -ac 2 -{$var.ab} 192k
profile.mp4_720.ext               = mp4
profile.mp4_720.width             = 1280
profile.mp4_720.height            = 720
profile.mp4_720.resize            = proportional
profile.mp4_720.force_divisible   = true
profile.mp4_720.faststart         = true
profile.mp4_720.filename_template =
profile.mp4_720.deinterlace_video = true
profile.mp4_720.deinterlace_auto  = 1

# 1920x1080 h264 High profile @ level 4.0 (8000kbps)
profile.mp4_1080.group             = Mp4 h.264
profile.mp4_1080.desc              = MP4 1920x1080 h264 High profile @ level 4.0, 8000k 
profile.mp4_1080.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 8000k -bt 8000k {$var.h264_fast}
profile.mp4_1080.audio_pass1       = -acodec {$var.AAC_LIB} -ar 48000 -ac 2 -{$var.ab} 192k
profile.mp4_1080.ext               = mp4
profile.mp4_1080.width             = 1920
profile.mp4_1080.height            = 1080
profile.mp4_1080.resize            = proportional
profile.mp4_1080.force_divisible   = true
profile.mp4_1080.faststart         = true
profile.mp4_1080.filename_template =
profile.mp4_1080.deinterlace_video = true
profile.mp4_1080.deinterlace_auto  = 1


# WINDOWS MEDIA VIDEO 8 PROFILES
# ==============================
#
# FFmpeg does not support WMV9, so we use WMV8 instead.
#

# wmv8 360p
profile.wmv_360.group             = Windows Media Video
profile.wmv_360.desc              = Windows Media Video 8 360p, 1500k
profile.wmv_360.video_pass1       = -{$var.vb} 1500k -vcodec wmv2
profile.wmv_360.audio_pass1       = -acodec wmav2 -ar 44100 -ac 2 -{$var.ab} 128k
profile.wmv_360.ext               = wmv
profile.wmv_360.width             = 640
profile.wmv_360.height            = 360
profile.wmv_360.resize            = proportional
profile.wmv_360.force_divisible   = true
profile.wmv_360.deinterlace_video = true
profile.wmv_360.deinterlace_auto  = 1

# wmv8 480p
profile.wmv_480.group             = Windows Media Video
profile.wmv_480.desc              = Windows Media Video 8 480p, 2500k
profile.wmv_480.video_pass1       = -{$var.vb} 2500k -vcodec wmv2
profile.wmv_480.audio_pass1       = -acodec wmav2 -ar 44100 -ac 2 -{$var.ab} 128k
profile.wmv_480.ext               = wmv
profile.wmv_480.width             = 854
profile.wmv_480.height            = 480
profile.wmv_480.resize            = proportional
profile.wmv_480.force_divisible   = true
profile.wmv_480.deinterlace_video = true
profile.wmv_480.deinterlace_auto  = 1

# wmv8 720p
profile.wmv_720.group             = Windows Media Video
profile.wmv_720.desc              = Windows Media Video 8 720p, 4500k
profile.wmv_720.video_pass1       = -{$var.vb} 4500k -vcodec wmv2
profile.wmv_720.audio_pass1       = -acodec wmav2 -ar 44100 -ac 2 -{$var.ab} 192k
profile.wmv_720.ext               = wmv
profile.wmv_720.width             = 1280
profile.wmv_720.height            = 720
profile.wmv_720.resize            = proportional
profile.wmv_720.force_divisible   = true
profile.wmv_720.deinterlace_video = true
profile.wmv_720.deinterlace_auto  = 1

# wmv8 1080p
profile.wmv_1080.group             = Windows Media Video
profile.wmv_1080.desc              = Windows Media Video 8 1080p, 8000k
profile.wmv_1080.video_pass1       = -{$var.vb} 8000k -vcodec wmv2
profile.wmv_1080.audio_pass1       = -acodec wmav2 -ar 44100 -ac 2 -{$var.ab} 192k
profile.wmv_1080.ext               = wmv
profile.wmv_1080.width             = 1920
profile.wmv_1080.height            = 1080
profile.wmv_1080.resize            = proportional
profile.wmv_1080.force_divisible   = true
profile.wmv_1080.deinterlace_video = true
profile.wmv_1080.deinterlace_auto  = 1


# MOBILE DEVICES PROFILES
# =======================
#
# The following profiles are optimiced for mobile devices. Note that the
# compatibility list is not exclusive.
#

# 176x144 h.263 BaseLine@1.0 apx. 300kbps
profile.3gp.group             = Mobile
profile.3gp.desc              = 3GP 176x144 h.263 BaseLine@1.0 apx. 300k
profile.3gp.video_pass1       = -vcodec h263 -r 25 -{$var.vb} 250k
profile.3gp.audio_pass1       = -acodec {$var.AAC_LIB} -ar 8000 -ac 1 -{$var.ab} 32k
profile.3gp.ext               = 3gp
profile.3gp.width             = 176
profile.3gp.height            = 144
profile.3gp.resize            = crop
profile.3gp.filename_template =
profile.3gp.deinterlace_video = true
profile.3gp.deinterlace_auto  = 1

# 640x360 h.264 baseline.
profile.mp4_360b_2p.group             = Mobile
profile.mp4_360b_2p.desc              = MP4 640x360 h264 Baseline profile @ level 3.0, 1300k (multipass). iPhone, iPad, Computer.
profile.mp4_360b_2p.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 1300k -bt 1300k {$var.h264_fast_firstpass} {$var.h264_baseline}
profile.mp4_360b_2p.video_pass2       = -vcodec libx264 -threads 0 -{$var.vb} 1300k -bt 1300k {$var.h264_fast} {$var.h264_baseline}
profile.mp4_360b_2p.audio_pass1       = -an
profile.mp4_360b_2p.audio_pass2       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_360b_2p.ext               = mp4
profile.mp4_360b_2p.width             = 640
profile.mp4_360b_2p.height            = 360
profile.mp4_360b_2p.resize            = proportional
profile.mp4_360b_2p.force_divisible   = true
profile.mp4_360b_2p.faststart         = false
profile.mp4_360b_2p.filename_template =
profile.mp4_360b_2p.deinterlace_video = true
profile.mp4_360b_2p.deinterlace_auto  = 1

# Nokia compatible h264 baseline @ L 2.1, multipass.
profile.mp4_180b_2p.group             = Mobile
profile.mp4_180b_2p.desc              = MP4 320x180 h264 Baseline profile @ level 2.1, 1024k (multipass). Nokia Nseries, iPhone, iPad, Computer.
profile.mp4_180b_2p.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 1024k -bt 2000k {$var.h264_fast_firstpass} {$var.h264_baseline}
profile.mp4_180b_2p.video_pass2       = -vcodec libx264 -threads 0 -{$var.vb} 1024k -bt 2000k {$var.h264_fast} {$var.h264_baseline}
profile.mp4_180b_2p.audio_pass1       = -an
profile.mp4_180b_2p.audio_pass2       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_180b_2p.ext               = mp4
profile.mp4_180b_2p.width             = 320
profile.mp4_180b_2p.height            = 180
profile.mp4_180b_2p.resize            = proportional
profile.mp4_180b_2p.force_divisible   = true
profile.mp4_180b_2p.faststart         = false
profile.mp4_180b_2p.filename_template =
profile.mp4_180b_2p.deinterlace_video = true
profile.mp4_180b_2p.deinterlace_auto  = 1

# Nokia compatible h264 baseline @ L 2.0
profile.mp4_180b.group             = Mobile
profile.mp4_180b.desc              = MP4 320x180 h264 Baseline profile @ level 2.0, 512k . Nokia Nseries, iPhone, iPad, Computer.
profile.mp4_180b.video_pass1       = -vcodec libx264 -threads 0 -{$var.vb} 512k -bt 512k {$var.h264_fast} {$var.h264_baseline}
profile.mp4_180b.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_180b.ext               = mp4
profile.mp4_180b.width             = 320
profile.mp4_180b.height            = 180
profile.mp4_180b.resize            = proportional
profile.mp4_180b.force_divisible   = true
profile.mp4_180b.faststart         = false
profile.mp4_180b.filename_template =
profile.mp4_180b.deinterlace_video = true
profile.mp4_180b.deinterlace_auto  = 1

# IPOD video, h264 baseline @ Level 1.3
profile.mp4_240b.group             = Mobile
profile.mp4_240b.desc              = MP4 320x240 h264 Baseline profile @ level 1.3, 768k . iPod 5th Gen (ipod video)+
profile.mp4_240b.video_pass1       = -f ipod -vcodec libx264 -threads 0 -{$var.vb} 768k {$var.h264_fast} {$var.h264_baseline} -level 13 -maxrate 768000 -bufsize 3000000
profile.mp4_240b.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mp4_240b.ext               = mp4
profile.mp4_240b.width             = 320
profile.mp4_240b.height            = 240
profile.mp4_240b.resize            = proportional
profile.mp4_240b.force_divisible   = true
profile.mp4_240b.faststart         = false
profile.mp4_240b.filename_template =
profile.mp4_240b.deinterlace_video = true
profile.mp4_240b.deinterlace_auto  = 1

# Nokia mpeg4, multipass.
profile.mpeg4_640_2p.group             = Mobile
profile.mpeg4_640_2p.desc              = MP4 640x480 (crop) mpeg4 simple @ level 1.0, 1500k (multipass)
profile.mpeg4_640_2p.video_pass1       = -vcodec mpeg4 -{$var.vb} 1500k
profile.mpeg4_640_2p.video_pass2       = -vcodec mpeg4 -{$var.vb} 1500k
profile.mpeg4_640_2p.audio_pass1       = -an
profile.mpeg4_640_2p.audio_pass2       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mpeg4_640_2p.ext               = mp4
profile.mpeg4_640_2p.width             = 640
profile.mpeg4_640_2p.height            = 480
profile.mpeg4_640_2p.resize            = crop
profile.mpeg4_640_2p.force_divisible   = true
profile.mpeg4_640_2p.faststart         = false
profile.mpeg4_640_2p.filename_template =
profile.mpeg4_640_2p.deinterlace_video = true
profile.mpeg4_640_2p.deinterlace_auto  = 1

# Nokia mpeg4
profile.mpeg4_640.group             = Mobile
profile.mpeg4_640.desc              = MP4 640x480 (crop) mpeg4 simple @ level 1.0, 1500k 
profile.mpeg4_640.video_pass1       = -vcodec mpeg4 -{$var.vb} 1500k
profile.mpeg4_640.audio_pass1       = -acodec {$var.AAC_LIB} -ar 44100 -ac 2 -{$var.ab} 128k
profile.mpeg4_640.ext               = mp4
profile.mpeg4_640.width             = 640
profile.mpeg4_640.height            = 480
profile.mpeg4_640.resize            = crop
profile.mpeg4_640.force_divisible   = true
profile.mpeg4_640.faststart         = false
profile.mpeg4_640.filename_template =
profile.mpeg4_640.deinterlace_video = true
profile.mpeg4_640.deinterlace_auto  = 1


# AUDIO EXTRACTION PROFILES
# =========================

# mp3 @128kbps
profile.mp3_128.group       = Extract Audio
profile.mp3_128.desc        = Extract audio to MP3 at 128k
profile.mp3_128.video_pass1 = -vn
profile.mp3_128.audio_pass1 = -acodec libmp3lame -{$var.ab} 128k
profile.mp3_128.ext         = mp3

# mp3 @192kbps
profile.mp3_192.group       = Extract Audio
profile.mp3_192.desc        = Extract audio to MP3 at 192k
profile.mp3_192.video_pass1 = -vn
profile.mp3_192.audio_pass1 = -acodec libmp3lame -{$var.ab} 192k
profile.mp3_192.ext         = mp3

# AAC (Advanced Audio Coding)
profile.aac_128.group       = Extract Audio
profile.aac_128.desc        = Extract audio to AAC at 128k
profile.aac_128.video_pass1 = -vn
profile.aac_128.audio_pass1 = -acodec {$var.AAC_LIB} -{$var.ab} 128k
profile.aac_128.ext         = aac

# AAC (Advanced Audio Coding)
profile.aac_192.group       = Extract Audio
profile.aac_192.desc        = Extract audio to AAC at 192k
profile.aac_192.video_pass1 = -vn
profile.aac_192.audio_pass1 = -acodec {$var.AAC_LIB} -{$var.ab} 192k
profile.aac_192.ext         = aac

# Vorbis audio in OGG container
profile.ogg_128.group       = Extract Audio
profile.ogg_128.desc        = Extract audio to Vorbis at 128k
profile.ogg_128.video_pass1 = -vn
profile.ogg_128.audio_pass1 = -acodec libvorbis -{$var.ab} 128k
profile.ogg_128.ext         = ogg

# Vorbis audio in OGG container
profile.ogg_192.group       = Extract Audio
profile.ogg_192.desc        = Extract audio to Vorbis at 192k
profile.ogg_192.video_pass1 = -vn
profile.ogg_192.audio_pass1 = -acodec libvorbis -{$var.ab} 192k
profile.ogg_192.ext         = ogg

# Apple AIFF PCM
profile.aiff.group       = Extract Audio
profile.aiff.desc        = Extract audio to AIFF PCM
profile.aiff.video_pass1 = -vn
profile.aiff.audio_pass1 =
profile.aiff.ext         = aiff

# Microsoft WAV PCM
profile.wav.group       = Extract Audio
profile.wav.desc        = Extract audio to WAV PCM
profile.wav.video_pass1 = -vn
profile.wav.audio_pass1 =
profile.wav.ext         = wav



# MISCELLANOUS PROFILES
# =====================
 
# Convert Apple HDV contained in MOV file to M2TS. Use only for HDV mov sources.
profile.m2ts.group       = Misc
profile.m2ts.desc        = Convert Apple HDV contained in MOV file to M2TS
profile.m2ts.video_pass1 = -f mpegts -vcodec copy
profile.m2ts.audio_pass1 = -acodec mp2 -ar 48000 -ac 2 -{$var.ab} 384k
profile.m2ts.ext         = m2ts
profile.m2ts.width       = 0
profile.m2ts.height      = 0



# FLV. FLASH VIDEO PROFILES
# =========================
#
# These profiles generate Flash 6 video files.
# Unfortunately On2 VP6 (flash 8) is not supported by FFmpeg due to licensing
# royalties.
#
# In general FLV is an old format to deliver flash video. You can use MP4 video
# with h.264 for flash, which provides better quality and broad compatibility.
#

# 360p, h263 old school flash 6 video.
profile.flv_360p.group             = Flv
profile.flv_360p.desc              = FLV 360p h.263, 1300k  (Flash 6)
profile.flv_360p.video_pass1       = -f flv -vcodec flv -{$var.vb} 1300k
profile.flv_360p.audio_pass1       = -acodec libmp3lame -ar 44100 -ac 2 -{$var.ab} 128k
profile.flv_360p.ext               = flv
profile.flv_360p.width             = 640
profile.flv_360p.height            = 360
profile.flv_360p.resize            = proportional
profile.flv_360p.force_divisible   = true
profile.flv_360p.faststart         = true
profile.flv_360p.filename_template =
profile.flv_360p.deinterlace_video = true
profile.flv_360p.deinterlace_auto  = 1

# 480p, h263 old school flash 6 video.
profile.flv_480p.group             = Flv
profile.flv_480p.desc              = FLV 480p h.263, 2100k  (Flash 6)
profile.flv_480p.video_pass1       = -f flv -vcodec flv -{$var.vb} 2100k
profile.flv_480p.audio_pass1       = -acodec libmp3lame -ar 44100 -ac 2 -{$var.ab} 128k
profile.flv_480p.ext               = flv
profile.flv_480p.width             = 854
profile.flv_480p.height            = 480
profile.flv_480p.resize            = proportional
profile.flv_480p.force_divisible   = true
profile.flv_480p.faststart         = true
profile.flv_480p.filename_template =
profile.flv_480p.deinterlace_video = true
profile.flv_480p.deinterlace_auto  = 1

# 720p, h263 old school flash 6 video.
profile.flv_720p.group             = Flv
profile.flv_720p.desc              = FLV 720p h.263, 2500k  (Flash 6)
profile.flv_720p.video_pass1       = -f flv -vcodec flv -{$var.vb} 2500k
profile.flv_720p.audio_pass1       = -acodec libmp3lame -ar 44100 -ac 2 -{$var.ab} 128k
profile.flv_720p.ext               = flv
profile.flv_720p.width             = 1280
profile.flv_720p.height            = 720
profile.flv_720p.resize            = proportional
profile.flv_720p.force_divisible   = true
profile.flv_720p.faststart         = true
profile.flv_720p.filename_template =
profile.flv_720p.deinterlace_video = true
profile.flv_720p.deinterlace_auto  = 1

# 1080p, h263 old school flash 6 video.
profile.flv_1080p.group             = Flv
profile.flv_1080p.desc              = FLV 1080p h.263, 8000k  (Flash 6)
profile.flv_1080p.video_pass1       = -f flv -vcodec flv -{$var.vb} 8000k
profile.flv_1080p.audio_pass1       = -acodec libmp3lame -ar 44100 -ac 2 -{$var.ab} 128k
profile.flv_1080p.ext               = flv
profile.flv_1080p.width             = 1920
profile.flv_1080p.height            = 1080
profile.flv_1080p.resize            = proportional
profile.flv_1080p.force_divisible   = false
profile.flv_1080p.faststart         = true
profile.flv_1080p.filename_template =
profile.flv_1080p.deinterlace_video = true
profile.flv_1080p.deinterlace_auto  = 1

#
# END of profiles :)
#
# Copyright (c) 2013 Tremendum Transcoder. All rights reserved.
#