#!/bin/sh

###############################################################################
#
# This shell script is to be called by a cron job, and it will only
# load the PHP engine if there's a run request.
#
# Copyright (c) 2013 Tremendum Transcoder. All rights reserved.
#
###############################################################################
# Settings START

# Path to PHP executable
PHP="/usr/local/bin/php"

# PHP Arguments
PHP_ARGS="-ddisable_functions= -dopen_basedir=/path/to/tt-private/"

# This must match your setting in tt-config.inc.php
FLAGS_FOLDER="/path/to/tt-private/flags"

# Full path to tt-cron.php file
TT_CRON="/path/to/tt-private/core/tt-cron.php"

# Settings END
###############################################################################


# Build PHP commandline
if [ "$PHP_ARGS" != "" ]; then
    PHP_CMD="$PHP $PHP_ARGS"
else
    PHP_CMD=$PHP
fi

# Shorthand
TT="tremendum_transcoder"

# Check if there is a kill request and proceed if we are running
if [ -f "$FLAGS_FOLDER/$TT.kill" ] && [ -f "$FLAGS_FOLDER/$TT.running" ] && [ -f "$FLAGS_FOLDER/$TT.pid" ]; then

    # Obtain the process ID
    PID=$(cat "$FLAGS_FOLDER/$TT.pid")

    # Prevent being tricked into executing arbitrary code or killing a random process
    if [ $PID -eq $PID 2> /dev/null ]; then
        RUNNING=$(ps -o command= -p $PID | grep "^$PHP")
	else
	    RUNNING=""
	fi

    # Kill the process group
    if [ "$RUNNING" != "" ]; then

        # Kill the process group
        kill -- -$(ps -o pgid= -p $PID | tr -d ' ')

        # Log the action
        echo -e "\n\nPROCESS KILLED PER USER REQUEST!\n" >> "$FLAGS_FOLDER/$TT.output"

        # Update status message
        echo -n "USER ABORTED OPERATION!!" > "$FLAGS_FOLDER/$TT.status"

    else

        # We failed to kill the process
        echo -e "\n\nUSER ABORTED OPERATION FAILED!! Could not find / verify running process.\n" >> "$FLAGS_FOLDER/$TT.output"

        # Update status message
        echo -n "FAILED TO ABORT OPERATION! Could not find / verify running process." > "$FLAGS_FOLDER/$TT.status"

    fi

    # Remove flags
    rm "$FLAGS_FOLDER/$TT.kill"
    rm "$FLAGS_FOLDER/$TT.pid"
    rm "$FLAGS_FOLDER/$TT.running"
    if [ -f "$FLAGS_FOLDER/$TT.abort" ]; then
        rm "$FLAGS_FOLDER/$TT.abort"
    fi

	
fi


# Check if there's a run request
if [ -f "$FLAGS_FOLDER/$TT.start" ]; then

   # Check that we are not already running
   if [ ! -f "$FLAGS_FOLDER/$TT.running" ]; then

      # We are not running, so call tt-cron and save the process ID
      $PHP_CMD "$TT_CRON" > "$FLAGS_FOLDER/$TT.log" 2>&1 & echo $! > "$FLAGS_FOLDER/$TT.pid"

   fi

fi


# EOF